==> cost-interface-0.3.6-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/AreaPointEventPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.AreaPointEventRegistVo;

import java.io.Serializable;
import java.util.Date;

/**
 * 区域点上事件营销核报
 * AreaPointEventPay
 * 数据库表：area_point_event_pay
 */
public class AreaPointEventPayVo implements Serializable {

    private static final long serialVersionUID = -811318181867276369L;

    /**对应登记单行项目信息*/
    private AreaPointEventRegistVo areaPointEventRegistVo;

    /**
     * 
     * 表字段 : area_point_event_pay.id
     */
    private Integer id;

    /**
     * 核报单号
     * 表字段 : area_point_event_pay.pay_no
     */
    private String payNo;

    /**
     * 行号
     * 表字段 : area_point_event_pay.item_no
     */
    private String itemNo;

    /**
     * 登记单号
     * 表字段 : area_point_event_pay.regist_no
     */
    private String registNo;

    /**
     * 登记单行项目号
     * 表字段 : area_point_event_pay.regist_item_no
     */
    private Integer registItemNo;

    /**
     * 申请单号
     * 表字段 : area_point_event_pay.apply_no
     */
    private String applyNo;

    /**
     * 费用类型编码
     * 表字段 : area_point_event_pay.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : area_point_event_pay.cost_type_name
     */
    private String costTypeName;

    /**
     * 活动形式
     * 表字段 : area_point_event_pay.activity_forms
     */
    private String activityForms;

    /**
     * 核报数量
     * 表字段 : area_point_event_pay.buy_num
     */
    private Integer buyNum;

    /**
     * 厂方承担金额(分)
     * 表字段 : area_point_event_pay.company_amount
     */
    private Long companyAmount;

    /**
     * 行项目余额
     */
    private Long itemBalance;

    /**
     * 核报金额(分)
     * 表字段 : area_point_event_pay.pay_amount
     */
    private Long payAmount;

    /**
     * 创建人Id
     * 表字段 : area_point_event_pay.create_id
     */
    private String createId;

    /**
     * 创建人
     * 表字段 : area_point_event_pay.create_name
     */
    private String createName;

    /**
     * 创建时间
     * 表字段 : area_point_event_pay.create_date
     */
    private Date createDate;

    /**
     * 修改人ID
     * 表字段 : area_point_event_pay.modify_id
     */
    private String modifyId;

    /**
     * 修改人
     * 表字段 : area_point_event_pay.modify_name
     */
    private String modifyName;

    /**
     * 修改时间
     * 表字段 : area_point_event_pay.modify_date
     */
    private Date modifyDate;

    /**
     * 获取  字段:area_point_event_pay.id
     *
     * @return area_point_event_pay.id, 
     */
    public Integer getId() {
        return id;
    }

    /**
     * 设置  字段:area_point_event_pay.id
     *
     * @param id the value for area_point_event_pay.id, 
     */
    public void setId(Integer id) {
        this.id = id;
    }

    public AreaPointEventRegistVo getAreaPointEventRegistVo() {
        return areaPointEventRegistVo;
    }

    public void setAreaPointEventRegistVo(AreaPointEventRegistVo areaPointEventRegistVo) {
        this.areaPointEventRegistVo = areaPointEventRegistVo;
    }

    /**
     * 获取 核报单号 字段:area_point_event_pay.pay_no
     *
     * @return area_point_event_pay.pay_no, 核报单号
     */
    public String getPayNo() {
        return payNo;
    }

    /**
     * 设置 核报单号 字段:area_point_event_pay.pay_no
     *
     * @param payNo the value for area_point_event_pay.pay_no, 核报单号
     */
    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    /**
     * 获取 行号 字段:area_point_event_pay.item_no
     *
     * @return area_point_event_pay.item_no, 行号
     */
    public String getItemNo() {
        return itemNo;
    }

    /**
     * 设置 行号 字段:area_point_event_pay.item_no
     *
     * @param itemNo the value for area_point_event_pay.item_no, 行号
     */
    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 获取 登记单号 字段:area_point_event_pay.regist_no
     *
     * @return area_point_event_pay.regist_no, 登记单号
     */
    public String getRegistNo() {
        return registNo;
    }

    /**
     * 设置 登记单号 字段:area_point_event_pay.regist_no
     *
     * @param registNo the value for area_point_event_pay.regist_no, 登记单号
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    /**
     * 获取 登记单行项目号 字段:area_point_event_pay.regist_item_no
     *
     * @return area_point_event_pay.regist_item_no, 登记单行项目号
     */
    public Integer getRegistItemNo() {
        return registItemNo;
    }

    /**
     * 设置 登记单行项目号 字段:area_point_event_pay.regist_item_no
     *
     * @param registItemNo the value for area_point_event_pay.regist_item_no, 登记单行项目号
     */
    public void setRegistItemNo(Integer registItemNo) {
        this.registItemNo = registItemNo;
    }

    /**
     * 获取 申请单号 字段:area_point_event_pay.apply_no
     *
     * @return area_point_event_pay.apply_no, 申请单号
     */
    public String getApplyNo() {
        return applyNo;
    }

    /**
     * 设置 申请单号 字段:area_point_event_pay.apply_no
     *
     * @param applyNo the value for area_point_event_pay.apply_no, 申请单号
     */
    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    /**
     * 获取 费用类型编码 字段:area_point_event_pay.cost_type_id
     *
     * @return area_point_event_pay.cost_type_id, 费用类型编码
     */
    public String getCostTypeId() {
        return costTypeId;
    }

    /**
     * 设置 费用类型编码 字段:area_point_event_pay.cost_type_id
     *
     * @param costTypeId the value for area_point_event_pay.cost_type_id, 费用类型编码
     */
    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    /**
     * 获取 费用类型名称 字段:area_point_event_pay.cost_type_name
     *
     * @return area_point_event_pay.cost_type_name, 费用类型名称
     */
    public String getCostTypeName() {
        return costTypeName;
    }

    /**
     * 设置 费用类型名称 字段:area_point_event_pay.cost_type_name
     *
     * @param costTypeName the value for area_point_event_pay.cost_type_name, 费用类型名称
     */
    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    /**
     * 获取 活动形式 字段:area_point_event_pay.activity_forms
     *
     * @return area_point_event_pay.activity_forms, 活动形式
     */
    public String getActivityForms() {
        return activityForms;
    }

    /**
     * 设置 活动形式 字段:area_point_event_pay.activity_forms
     *
     * @param activityForms the value for area_point_event_pay.activity_forms, 活动形式
     */
    public void setActivityForms(String activityForms) {
        this.activityForms = activityForms;
    }

    /**
     * 获取 核报数量 字段:area_point_event_pay.buy_num
     *
     * @return area_point_event_pay.buy_num, 核报数量
     */
    public Integer getBuyNum() {
        return buyNum;
    }

    /**
     * 设置 核报数量 字段:area_point_event_pay.buy_num
     *
     * @param buyNum the value for area_point_event_pay.buy_num, 核报数量
     */
    public void setBuyNum(Integer buyNum) {
        this.buyNum = buyNum;
    }

    /**
     * 获取 厂方承担金额(分) 字段:area_point_event_pay.company_amount
     *
     * @return area_point_event_pay.company_amount, 厂方承担金额(分)
     */
    public Long getCompanyAmount() {
        return companyAmount;
    }

    /**
     * 设置 厂方承担金额(分) 字段:area_point_event_pay.company_amount
     *
     * @param companyAmount the value for area_point_event_pay.company_amount, 厂方承担金额(分)
     */
    public void setCompanyAmount(Long companyAmount) {
        this.companyAmount = companyAmount;
    }

    public Long getItemBalance() {
        return itemBalance;
    }

    public void setItemBalance(Long itemBalance) {
        this.itemBalance = itemBalance;
    }

    /**
     * 获取 核报金额(分) 字段:area_point_event_pay.pay_amount
     *
     * @return area_point_event_pay.pay_amount, 核报金额(分)
     */
    public Long getPayAmount() {
        return payAmount;
    }

    /**
     * 设置 核报金额(分) 字段:area_point_event_pay.pay_amount
     *
     * @param payAmount the value for area_point_event_pay.pay_amount, 核报金额(分)
     */
    public void setPayAmount(Long payAmount) {
        this.payAmount = payAmount;
    }

    /**
     * 获取  字段:area_point_event_pay.create_id
     *
     * @return area_point_event_pay.create_id, 
     */
    public String getCreateId() {
        return createId;
    }

    /**
     * 设置  字段:area_point_event_pay.create_id
     *
     * @param createId the value for area_point_event_pay.create_id, 
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     * 获取  字段:area_point_event_pay.create_name
     *
     * @return area_point_event_pay.create_name, 
     */
    public String getCreateName() {
        return createName;
    }

    /**
     * 设置  字段:area_point_event_pay.create_name
     *
     * @param createName the value for area_point_event_pay.create_name, 
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     * 获取  字段:area_point_event_pay.create_date
     *
     * @return area_point_event_pay.create_date, 
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 设置  字段:area_point_event_pay.create_date
     *
     * @param createDate the value for area_point_event_pay.create_date, 
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 获取  字段:area_point_event_pay.modify_id
     *
     * @return area_point_event_pay.modify_id, 
     */
    public String getModifyId() {
        return modifyId;
    }

    /**
     * 设置  字段:area_point_event_pay.modify_id
     *
     * @param modifyId the value for area_point_event_pay.modify_id, 
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     * 获取  字段:area_point_event_pay.modify_name
     *
     * @return area_point_event_pay.modify_name, 
     */
    public String getModifyName() {
        return modifyName;
    }

    /**
     * 设置  字段:area_point_event_pay.modify_name
     *
     * @param modifyName the value for area_point_event_pay.modify_name, 
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     * 获取  字段:area_point_event_pay.modify_date
     *
     * @return area_point_event_pay.modify_date, 
     */
    public Date getModifyDate() {
        return modifyDate;
    }

    /**
     * 设置  字段:area_point_event_pay.modify_date
     *
     * @param modifyDate the value for area_point_event_pay.modify_date, 
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
}

==> cost-interface-0.3.10-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/AreaPointEventPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.AreaPointEventRegistVo;

import java.io.Serializable;
import java.util.Date;

/**
 * 区域点上事件营销核报
 * AreaPointEventPay
 * 数据库表：area_point_event_pay
 */
public class AreaPointEventPayVo implements Serializable {

    private static final long serialVersionUID = -811318181867276369L;

    /**对应登记单行项目信息*/
    private AreaPointEventRegistVo areaPointEventRegistVo;

    /**
     * 
     * 表字段 : area_point_event_pay.id
     */
    private Integer id;

    /**
     * 核报单号
     * 表字段 : area_point_event_pay.pay_no
     */
    private String payNo;

    /**
     * 行号
     * 表字段 : area_point_event_pay.item_no
     */
    private Integer itemNo;

    /**
     * 登记单号
     * 表字段 : area_point_event_pay.regist_no
     */
    private String registNo;

    /**
     * 登记单行项目号
     * 表字段 : area_point_event_pay.regist_item_no
     */
    private Integer registItemNo;

    /**
     * 申请单号
     * 表字段 : area_point_event_pay.apply_no
     */
    private String applyNo;

    /**
     * 费用类型编码
     * 表字段 : area_point_event_pay.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : area_point_event_pay.cost_type_name
     */
    private String costTypeName;

    /**
     * 活动形式
     * 表字段 : area_point_event_pay.activity_forms
     */
    private String activityForms;

    /**
     * 核报数量
     * 表字段 : area_point_event_pay.buy_num
     */
    private Integer buyNum;

    /**
     * 厂方承担金额(分)
     * 表字段 : area_point_event_pay.company_amount
     */
    private Long companyAmount;

    /**
     * 行项目余额
     */
    private Long itemBalance;

    /**
     * 核报金额(分)
     * 表字段 : area_point_event_pay.pay_amount
     */
    private Long payAmount;

    /**
     * 创建人Id
     * 表字段 : area_point_event_pay.create_id
     */
    private String createId;

    /**
     * 创建人
     * 表字段 : area_point_event_pay.create_name
     */
    private String createName;

    /**
     * 创建时间
     * 表字段 : area_point_event_pay.create_date
     */
    private Date createDate;

    /**
     * 修改人ID
     * 表字段 : area_point_event_pay.modify_id
     */
    private String modifyId;

    /**
     * 修改人
     * 表字段 : area_point_event_pay.modify_name
     */
    private String modifyName;

    /**
     * 修改时间
     * 表字段 : area_point_event_pay.modify_date
     */
    private Date modifyDate;

    /**
     * 获取  字段:area_point_event_pay.id
     *
     * @return area_point_event_pay.id, 
     */
    public Integer getId() {
        return id;
    }

    /**
     * 设置  字段:area_point_event_pay.id
     *
     * @param id the value for area_point_event_pay.id, 
     */
    public void setId(Integer id) {
        this.id = id;
    }

    public AreaPointEventRegistVo getAreaPointEventRegistVo() {
        return areaPointEventRegistVo;
    }

    public void setAreaPointEventRegistVo(AreaPointEventRegistVo areaPointEventRegistVo) {
        this.areaPointEventRegistVo = areaPointEventRegistVo;
    }

    /**
     * 获取 核报单号 字段:area_point_event_pay.pay_no
     *
     * @return area_point_event_pay.pay_no, 核报单号
     */
    public String getPayNo() {
        return payNo;
    }

    /**
     * 设置 核报单号 字段:area_point_event_pay.pay_no
     *
     * @param payNo the value for area_point_event_pay.pay_no, 核报单号
     */
    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    /**
     * 获取 行号 字段:area_point_event_pay.item_no
     *
     * @return area_point_event_pay.item_no, 行号
     */
    public Integer getItemNo() {
        return itemNo;
    }

    /**
     * 设置 行号 字段:area_point_event_pay.item_no
     *
     * @param itemNo the value for area_point_event_pay.item_no, 行号
     */
    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 获取 登记单号 字段:area_point_event_pay.regist_no
     *
     * @return area_point_event_pay.regist_no, 登记单号
     */
    public String getRegistNo() {
        return registNo;
    }

    /**
     * 设置 登记单号 字段:area_point_event_pay.regist_no
     *
     * @param registNo the value for area_point_event_pay.regist_no, 登记单号
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    /**
     * 获取 登记单行项目号 字段:area_point_event_pay.regist_item_no
     *
     * @return area_point_event_pay.regist_item_no, 登记单行项目号
     */
    public Integer getRegistItemNo() {
        return registItemNo;
    }

    /**
     * 设置 登记单行项目号 字段:area_point_event_pay.regist_item_no
     *
     * @param registItemNo the value for area_point_event_pay.regist_item_no, 登记单行项目号
     */
    public void setRegistItemNo(Integer registItemNo) {
        this.registItemNo = registItemNo;
    }

    /**
     * 获取 申请单号 字段:area_point_event_pay.apply_no
     *
     * @return area_point_event_pay.apply_no, 申请单号
     */
    public String getApplyNo() {
        return applyNo;
    }

    /**
     * 设置 申请单号 字段:area_point_event_pay.apply_no
     *
     * @param applyNo the value for area_point_event_pay.apply_no, 申请单号
     */
    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    /**
     * 获取 费用类型编码 字段:area_point_event_pay.cost_type_id
     *
     * @return area_point_event_pay.cost_type_id, 费用类型编码
     */
    public String getCostTypeId() {
        return costTypeId;
    }

    /**
     * 设置 费用类型编码 字段:area_point_event_pay.cost_type_id
     *
     * @param costTypeId the value for area_point_event_pay.cost_type_id, 费用类型编码
     */
    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    /**
     * 获取 费用类型名称 字段:area_point_event_pay.cost_type_name
     *
     * @return area_point_event_pay.cost_type_name, 费用类型名称
     */
    public String getCostTypeName() {
        return costTypeName;
    }

    /**
     * 设置 费用类型名称 字段:area_point_event_pay.cost_type_name
     *
     * @param costTypeName the value for area_point_event_pay.cost_type_name, 费用类型名称
     */
    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    /**
     * 获取 活动形式 字段:area_point_event_pay.activity_forms
     *
     * @return area_point_event_pay.activity_forms, 活动形式
     */
    public String getActivityForms() {
        return activityForms;
    }

    /**
     * 设置 活动形式 字段:area_point_event_pay.activity_forms
     *
     * @param activityForms the value for area_point_event_pay.activity_forms, 活动形式
     */
    public void setActivityForms(String activityForms) {
        this.activityForms = activityForms;
    }

    /**
     * 获取 核报数量 字段:area_point_event_pay.buy_num
     *
     * @return area_point_event_pay.buy_num, 核报数量
     */
    public Integer getBuyNum() {
        return buyNum;
    }

    /**
     * 设置 核报数量 字段:area_point_event_pay.buy_num
     *
     * @param buyNum the value for area_point_event_pay.buy_num, 核报数量
     */
    public void setBuyNum(Integer buyNum) {
        this.buyNum = buyNum;
    }

    /**
     * 获取 厂方承担金额(分) 字段:area_point_event_pay.company_amount
     *
     * @return area_point_event_pay.company_amount, 厂方承担金额(分)
     */
    public Long getCompanyAmount() {
        return companyAmount;
    }

    /**
     * 设置 厂方承担金额(分) 字段:area_point_event_pay.company_amount
     *
     * @param companyAmount the value for area_point_event_pay.company_amount, 厂方承担金额(分)
     */
    public void setCompanyAmount(Long companyAmount) {
        this.companyAmount = companyAmount;
    }

    public Long getItemBalance() {
        return itemBalance;
    }

    public void setItemBalance(Long itemBalance) {
        this.itemBalance = itemBalance;
    }

    /**
     * 获取 核报金额(分) 字段:area_point_event_pay.pay_amount
     *
     * @return area_point_event_pay.pay_amount, 核报金额(分)
     */
    public Long getPayAmount() {
        return payAmount;
    }

    /**
     * 设置 核报金额(分) 字段:area_point_event_pay.pay_amount
     *
     * @param payAmount the value for area_point_event_pay.pay_amount, 核报金额(分)
     */
    public void setPayAmount(Long payAmount) {
        this.payAmount = payAmount;
    }

    /**
     * 获取  字段:area_point_event_pay.create_id
     *
     * @return area_point_event_pay.create_id, 
     */
    public String getCreateId() {
        return createId;
    }

    /**
     * 设置  字段:area_point_event_pay.create_id
     *
     * @param createId the value for area_point_event_pay.create_id, 
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     * 获取  字段:area_point_event_pay.create_name
     *
     * @return area_point_event_pay.create_name, 
     */
    public String getCreateName() {
        return createName;
    }

    /**
     * 设置  字段:area_point_event_pay.create_name
     *
     * @param createName the value for area_point_event_pay.create_name, 
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     * 获取  字段:area_point_event_pay.create_date
     *
     * @return area_point_event_pay.create_date, 
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 设置  字段:area_point_event_pay.create_date
     *
     * @param createDate the value for area_point_event_pay.create_date, 
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 获取  字段:area_point_event_pay.modify_id
     *
     * @return area_point_event_pay.modify_id, 
     */
    public String getModifyId() {
        return modifyId;
    }

    /**
     * 设置  字段:area_point_event_pay.modify_id
     *
     * @param modifyId the value for area_point_event_pay.modify_id, 
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     * 获取  字段:area_point_event_pay.modify_name
     *
     * @return area_point_event_pay.modify_name, 
     */
    public String getModifyName() {
        return modifyName;
    }

    /**
     * 设置  字段:area_point_event_pay.modify_name
     *
     * @param modifyName the value for area_point_event_pay.modify_name, 
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     * 获取  字段:area_point_event_pay.modify_date
     *
     * @return area_point_event_pay.modify_date, 
     */
    public Date getModifyDate() {
        return modifyDate;
    }

    /**
     * 设置  字段:area_point_event_pay.modify_date
     *
     * @param modifyDate the value for area_point_event_pay.modify_date, 
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
}
